package com.qmth.distributed.print.business.templete.execute;

import com.qmth.distributed.print.business.entity.ExamPaperStructure;
import com.qmth.distributed.print.business.service.DataSyncService;
import com.qmth.teachcloud.common.entity.SysConfig;
import com.qmth.teachcloud.common.service.SysConfigService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 异步同步云阅卷
 */
@Service
public class AsyncCloudMarkingTaskService {

    private final static Logger log = LoggerFactory.getLogger(AsyncCloudMarkingTaskService.class);

    @Resource
    private SysConfigService sysConfigService;

    @Resource
    private DataSyncService dataSyncService;

    private boolean isSync() {
        SysConfig sysConfig = sysConfigService.getByKey("sys.sync.enable");
        return sysConfig != null && "true".equals(sysConfig.getConfigValue());
    }

    /**
     * 同步试卷结构、分组信息、评卷员绑定关系
     *
     * @param examPaperStructure 试卷结构对象
     */
    public void syncPaperStructureAndGroup(ExamPaperStructure examPaperStructure) {
        if (isSync()) {
            dataSyncService.syncPaperStructureAndGroup(examPaperStructure);
        }
    }

    /**
     * 同步试卷文件、标签文件
     *
     * @param examPaperStructure 试卷结构对象
     */
    public void syncPaperAndAnswer(ExamPaperStructure examPaperStructure) {
        if (isSync()) {
            dataSyncService.syncPaperAndAnswer(examPaperStructure);
        }
    }

    /**
     * 同步客观题答案
     *
     * @param examPaperStructure 试卷结构对象
     */
    public void syncObjectiveStructure(ExamPaperStructure examPaperStructure) {
        if (isSync()) {
            dataSyncService.syncObjectiveStructure(examPaperStructure);
        }
    }
}
